==> icons-vue-0.3.0.tgz: package/es/user--simulation/16.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_UserSimulation16 = {
  name: 'UserSimulation16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M25.232 12.866H29.232V14.866H25.232z",
        "transform": "rotate(30 27.232 13.866)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26 8H30V10H26z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M2.768 12.866H6.768V14.866H2.768z",
        "transform": "rotate(150 4.768 13.866)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26 30H24V25a5.0059 5.0059 0 0 0-5-5H13a5.0059 5.0059 0 0 0-5 5v5H6V25a7.0082 7.0082 0 0 1 7-7h6a7.0082 7.0082 0 0 1 7 7zM16 4a5 5 0 1 1-5 5 5 5 0 0 1 5-5m0-2a7 7 0 1 0 7 7A7 7 0 0 0 16 2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M25.232 3.134H29.232V5.134H25.232z",
        "transform": "rotate(-30 27.232 4.134)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M2 8H6V10H2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M2.768 3.134H6.768V5.134H2.768z",
        "transform": "rotate(-150 4.768 4.134)"
      }
    }), children]);
  }
};

export default virtual_UserSimulation16;

==> icons-vue-0.6.0.tgz: package/es/user--simulation/16.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_UserSimulation16 = {
  name: 'UserSimulation16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "25.232",
        "y": "12.866",
        "transform": "rotate(30 27.232 13.866)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "26",
        "y": "8"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "2.768",
        "y": "12.866",
        "transform": "rotate(150 4.768 13.866)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26,30H24V25a5.0059,5.0059,0,0,0-5-5H13a5.0059,5.0059,0,0,0-5,5v5H6V25a7.0082,7.0082,0,0,1,7-7h6a7.0082,7.0082,0,0,1,7,7Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,4a5,5,0,1,1-5,5,5,5,0,0,1,5-5m0-2a7,7,0,1,0,7,7A7,7,0,0,0,16,2Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "25.232",
        "y": "3.134",
        "transform": "rotate(-30 27.232 4.134)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "2",
        "y": "8"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "2.768",
        "y": "3.134",
        "transform": "rotate(-150 4.768 4.134)"
      }
    }), children]);
  }
};

export default virtual_UserSimulation16;
